# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`dkms`](#dkms): Install DKMS and optional service
* [`dkms::autoinstall`](#dkmsautoinstall): Just a place to run autoinstall

#### Private Classes

* `dkms::install`: A class to track the installed state of the software

### Defined types

* [`dkms::kernel_module`](#dkmskernel_module): Setup a kernel module for DKMS

## Classes

### <a name="dkms"></a>`dkms`

Install DKMS and optional service

#### Examples

##### 

```puppet
include dkms
```

#### Parameters

The following parameters are available in the `dkms` class:

* [`package_manage`](#package_manage)
* [`package_names`](#package_names)
* [`package_ensure`](#package_ensure)
* [`kernel_devel_package_manage`](#kernel_devel_package_manage)
* [`kernel_devel_package_names`](#kernel_devel_package_names)
* [`kernel_devel_package_ensure`](#kernel_devel_package_ensure)
* [`service_manage`](#service_manage)
* [`service_names`](#service_names)
* [`service_ensure`](#service_ensure)
* [`service_enable`](#service_enable)
* [`kernel_modules`](#kernel_modules)

##### <a name="package_manage"></a>`package_manage`

Data type: `Boolean`

should we manage the dkms package?

##### <a name="package_names"></a>`package_names`

Data type: `Array`

any package names for dkms

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

ensure for the dkms packages

##### <a name="kernel_devel_package_manage"></a>`kernel_devel_package_manage`

Data type: `Boolean`

should we manage the kernel-devel package?

##### <a name="kernel_devel_package_names"></a>`kernel_devel_package_names`

Data type: `Array`

any package names for kernel-devel

##### <a name="kernel_devel_package_ensure"></a>`kernel_devel_package_ensure`

Data type: `String`

ensure for the kernel-devel packages

##### <a name="service_manage"></a>`service_manage`

Data type: `Boolean`

should we manage a dkms service?

##### <a name="service_names"></a>`service_names`

Data type: `Array`

names of any dkms services

##### <a name="service_ensure"></a>`service_ensure`

Data type: `String`

ensure for the dkms services

##### <a name="service_enable"></a>`service_enable`

Data type: `Boolean`

enable for the dkms services

##### <a name="kernel_modules"></a>`kernel_modules`

Data type: `Hash`

create these `dkms::kernel_module` resources

### <a name="dkmsautoinstall"></a>`dkms::autoinstall`

Just a place to run autoinstall

#### Examples

##### 

```puppet
include dkms::autoinstall
```

#### Parameters

The following parameters are available in the `dkms::autoinstall` class:

* [`timeout`](#timeout)

##### <a name="timeout"></a>`timeout`

Data type: `Integer`

this is the exec timeout

## Defined types

### <a name="dkmskernel_module"></a>`dkms::kernel_module`

Setup a kernel module for DKMS

#### Examples

##### 

```puppet
dkms::kernel_module { 'openafs':
  kmod_version => '1.8.2',
}

dkms::kernel_module { 'my clean title':
  kmod_name    => 'openafs',
  kmod_version => '1.8.2',
  ensure       => 'installed',
}
```

#### Parameters

The following parameters are available in the `dkms::kernel_module` defined type:

* [`kmod_version`](#kmod_version)
* [`kmod_name`](#kmod_name)
* [`ensure`](#ensure)
* [`on_kernel`](#on_kernel)
* [`build_timeout`](#build_timeout)
* [`use_autoinstall`](#use_autoinstall)

##### <a name="kmod_version"></a>`kmod_version`

Data type: `Variant[String, Integer]`

The version of this kernel module

##### <a name="kmod_name"></a>`kmod_name`

Data type: `String`

The name of this kernel module

Default value: `$title`

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'built', 'installed', 'absent']`

Should this be, added (present), built, installed, or absent?
The `built` or `installed` option will actually run the compile
as part of the puppet run and may require an increased `build_timeout`.

Default value: `'present'`

##### <a name="on_kernel"></a>`on_kernel`

Data type: `String`

Which kernel should we track.
If you set this to `ALL`, it will select all kernels

Default value: `$facts['kernelrelease']`

##### <a name="build_timeout"></a>`build_timeout`

Data type: `Integer`

How long should we wait for the module to compile

Default value: `600`

##### <a name="use_autoinstall"></a>`use_autoinstall`

Data type: `Boolean`

Should we run `dkms autoinstall` afterwards?

Default value: ``false``

